aboutsummaryrefslogtreecommitdiff
path: root/src/include/ipxe/efi
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/ipxe/efi')
-rw-r--r--src/include/ipxe/efi/efi_pci.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/include/ipxe/efi/efi_pci.h b/src/include/ipxe/efi/efi_pci.h
index b280d80..e06473d 100644
--- a/src/include/ipxe/efi/efi_pci.h
+++ b/src/include/ipxe/efi/efi_pci.h
@@ -33,14 +33,14 @@ extern int efipci_write ( struct pci_device *pci, unsigned long location,
unsigned long value );
/**
- * Determine maximum PCI bus number within system
+ * Determine number of PCI buses within system
*
* @ret max_bus Maximum bus number
*/
static inline __always_inline int
-PCIAPI_INLINE ( efi, pci_max_bus ) ( void ) {
+PCIAPI_INLINE ( efi, pci_num_bus ) ( void ) {
/* No way to work this out via EFI */
- return 0xff;
+ return 0x100;
}
/**
@@ -33,14 +33,14 @@ extern int efipci_write ( struct pci_device *pci, unsigned long location,
*
- * @ret max_bus Maximum bus number
+ * @ret num_bus Number of buses
*/
static inline __always_inline int